pub struct Camera {
pub intrinsics: Intrinsics,
pub extrinsics: Extrinsics,
}Expand description
A camera has intrinsic and extrinsic parameters. Warning: extrinsics here is the pose of the camera, not directly the projection matrix parameters.
As it stands, it is currently limited to the pinhole camera model.
Fields
intrinsics: IntrinsicsIntrinsic parameters of the camera.
extrinsics: ExtrinsicsExtrinsic parameters of the camera pose.
Implementations
Sourceimpl Camera
impl Camera
Sourcepub fn new(intrinsics: Intrinsics, extrinsics: Extrinsics) -> Self
pub fn new(intrinsics: Intrinsics, extrinsics: Extrinsics) -> Self
Initialize a camera from intrinsic and extrinsic parameters.
Sourcepub fn project(&self, point: Point3) -> Vec3
pub fn project(&self, point: Point3) -> Vec3
Project a 3D point into its corresponding pixel in the image generated by the camera.
Result is still in homogeneous coordinates (thus Vec3).
Sourcepub fn back_project(&self, point: Point2, depth: Float) -> Point3
pub fn back_project(&self, point: Point2, depth: Float) -> Point3
From a 2D pixel position and a depth info, back project this point into the 3D world.