Module optimizer

Module optimizer 

Guiding traits to implement iterative optimization algorithms.

Enums

Continue
Enum used to indicate if iterations should continue or stop. Must be returned by the stop_criterion function.

Traits

State
An State<Observations, EvalState, Model, Error> is capable of iteratively minimizing an energy function, if provided few functions that are evaluated during iterations.